==> jc-1.4.0.tar.gz: soot/jimple/internal/JIdentityStmt.h <==
// public class soot.jimple.internal.JIdentityStmt

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2492f1f7a753b788 soot_AbstractUnit
// @dep_class edca39c912a872fb soot_jimple_internal_AbstractDefinitionStmt
// @dep_class b3c0d2cd30f6acdd soot_jimple_internal_AbstractStmt
// @dep_class b38b5e2548c0bae9 soot_jimple_internal_JIdentityStmt
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_jimple_internal_AbstractDefinitionStmt

#include "soot/jimple/internal/AbstractDefinitionStmt.h"

#ifndef _JC_soot_jimple_internal_JIdentityStmt_H_
#define _JC_soot_jimple_internal_JIdentityStmt_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_List$object;
struct _jc_soot_UnitPrinter$object;
struct _jc_soot_Value$object;
struct _jc_soot_ValueBox$object;
struct _jc_soot_jimple_JimpleToBafContext$object;
struct _jc_soot_util_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_internal_JIdentityStmt$sub_refs	_jc_soot_jimple_internal_JIdentityStmt$sub_refs;
typedef struct _jc_soot_jimple_internal_JIdentityStmt$sub_nonrefs	_jc_soot_jimple_internal_JIdentityStmt$sub_nonrefs;
typedef struct _jc_soot_jimple_internal_JIdentityStmt$refs	_jc_soot_jimple_internal_JIdentityStmt$refs;
typedef struct _jc_soot_jimple_internal_JIdentityStmt$nonrefs	_jc_soot_jimple_internal_JIdentityStmt$nonrefs;
typedef struct _jc_soot_jimple_internal_JIdentityStmt$object	_jc_soot_jimple_internal_JIdentityStmt$object;

typedef const struct _jc_soot_jimple_internal_JIdentityStmt$vmethods	_jc_soot_jimple_internal_JIdentityStmt$vmethods;
typedef const struct _jc_soot_jimple_internal_JIdentityStmt$vtable	_jc_soot_jimple_internal_JIdentityStmt$vtable;
typedef const struct _jc_soot_jimple_internal_JIdentityStmt$vtype	_jc_soot_jimple_internal_JIdentityStmt$vtype;

// Constructors
extern void _jc_soot_jimple_internal_JIdentityStmt$method$_init$b3c9ec81c7d0a5b0(_jc_env *, struct _jc_soot_jimple_internal_JIdentityStmt$object *, struct _jc_object *, struct _jc_object *);
extern void _jc_soot_jimple_internal_JIdentityStmt$method$_init$76c8b23810ae9526(_jc_env *, struct _jc_soot_jimple_internal_JIdentityStmt$object *, struct _jc_object *, struct _jc_object *);

// Virtual methods
extern void _jc_soot_jimple_internal_JIdentityStmt$method$apply$cd67f53165014a6d(_jc_env *, struct _jc_soot_jimple_internal_JIdentityStmt$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_internal_JIdentityStmt$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_internal_JIdentityStmt$object *);
extern void _jc_soot_jimple_internal_JIdentityStmt$method$convertToBaf$0357e46cf55b475a(_jc_env *, struct _jc_soot_jimple_internal_JIdentityStmt$object *, struct _jc_soot_jimple_JimpleToBafContext$object *, struct _jc_object *);
extern void _jc_soot_jimple_internal_JIdentityStmt$method$setLeftOp$8889dbc4befe13b8(_jc_env *, struct _jc_soot_jimple_internal_JIdentityStmt$object *, struct _jc_object *);
extern void _jc_soot_jimple_internal_JIdentityStmt$method$setRightOp$43827eda9181e3de(_jc_env *, struct _jc_soot_jimple_internal_JIdentityStmt$object *, struct _jc_object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_internal_JIdentityStmt$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_internal_JIdentityStmt$object *);
extern void _jc_soot_jimple_internal_JIdentityStmt$method$toString$49ce0d4a4e59c2a6(_jc_env *, struct _jc_soot_jimple_internal_JIdentityStmt$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_internal_JIdentityStmt$method_info$apply$cd67f53165014a6d;
extern _jc_method _jc_soot_jimple_internal_JIdentityStmt$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_internal_JIdentityStmt$method_info$convertToBaf$0357e46cf55b475a;
extern _jc_method _jc_soot_jimple_internal_JIdentityStmt$method_info$setLeftOp$8889dbc4befe13b8;
extern _jc_method _jc_soot_jimple_internal_JIdentityStmt$method_info$setRightOp$43827eda9181e3de;
extern _jc_method _jc_soot_jimple_internal_JIdentityStmt$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_soot_jimple_internal_JIdentityStmt$method_info$toString$49ce0d4a4e59c2a6;

// Virtual methods structure
struct _jc_soot_jimple_internal_JIdentityStmt$vmethods {
	void	(*apply$cd67f53165014a6d)(_jc_env *, struct _jc_soot_jimple_internal_JIdentityStmt$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_internal_JIdentityStmt$object *);
	void	(*convertToBaf$0357e46cf55b475a)(_jc_env *, struct _jc_soot_jimple_internal_JIdentityStmt$object *, struct _jc_soot_jimple_JimpleToBafContext$object *, struct _jc_object *);
	void	(*setLeftOp$8889dbc4befe13b8)(_jc_env *, struct _jc_soot_jimple_internal_JIdentityStmt$object *, struct _jc_object *);
	void	(*setRightOp$43827eda9181e3de)(_jc_env *, struct _jc_soot_jimple_internal_JIdentityStmt$object *, struct _jc_object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_internal_JIdentityStmt$object *);
	void	(*toString$49ce0d4a4e59c2a6)(_jc_env *, struct _jc_soot_jimple_internal_JIdentityStmt$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_jimple_internal_JIdentityStmt$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractUnit$vmethods	soot_AbstractUnit;
	_jc_soot_jimple_internal_AbstractStmt$vmethods	soot_jimple_internal_AbstractStmt;
	_jc_soot_jimple_internal_AbstractDefinitionStmt$vmethods	soot_jimple_internal_AbstractDefinitionStmt;
	_jc_soot_jimple_internal_JIdentityStmt$vmethods	soot_jimple_internal_JIdentityStmt;
};

// Vtype
struct _jc_soot_jimple_internal_JIdentityStmt$vtype {
	_jc_type			type;
	_jc_soot_jimple_internal_JIdentityStmt$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_internal_JIdentityStmt$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_internal_JIdentityStmt$refs {
    _jc_soot_jimple_internal_JIdentityStmt$sub_refs	soot_jimple_internal_JIdentityStmt;
    _jc_soot_jimple_internal_AbstractDefinitionStmt$sub_refs	soot_jimple_internal_AbstractDefinitionStmt;
    _jc_soot_jimple_internal_AbstractStmt$sub_refs	soot_jimple_internal_AbstractStmt;
    _jc_soot_AbstractUnit$sub_refs	soot_AbstractUnit;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_internal_JIdentityStmt$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_internal_JIdentityStmt$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractUnit$sub_nonrefs	soot_AbstractUnit;
    _jc_soot_jimple_internal_AbstractStmt$sub_nonrefs	soot_jimple_internal_AbstractStmt;
    _jc_soot_jimple_internal_AbstractDefinitionStmt$sub_nonrefs	soot_jimple_internal_AbstractDefinitionStmt;
    _jc_soot_jimple_internal_JIdentityStmt$sub_nonrefs	soot_jimple_internal_JIdentityStmt;
};

// Object instance structure
struct _jc_soot_jimple_internal_JIdentityStmt$object {
	_jc_soot_jimple_internal_JIdentityStmt$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_internal_JIdentityStmt$vtype	*vtype;
	_jc_soot_jimple_internal_JIdentityStmt$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_internal_JIdentityStmt$vtype _jc_soot_jimple_internal_JIdentityStmt$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_internal_JIdentityStmt, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_internal_JIdentityStmt$class_object;

#endif	/* _JC_soot_jimple_internal_JIdentityStmt_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/internal/JIdentityStmt.h <==
// public class soot.jimple.internal.JIdentityStmt

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2492f1f7a753b788 soot_AbstractUnit
// @dep_class edca39c912a872fb soot_jimple_internal_AbstractDefinitionStmt
// @dep_class b3c0d2cd30f6acdd soot_jimple_internal_AbstractStmt
// @dep_class b38b5e2548c0bae9 soot_jimple_internal_JIdentityStmt
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_jimple_internal_AbstractDefinitionStmt

#include "soot/jimple/internal/AbstractDefinitionStmt.h"

#ifndef _JC_soot_jimple_internal_JIdentityStmt_H_
#define _JC_soot_jimple_internal_JIdentityStmt_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_List$object;
struct _jc_soot_UnitPrinter$object;
struct _jc_soot_Value$object;
struct _jc_soot_ValueBox$object;
struct _jc_soot_jimple_JimpleToBafContext$object;
struct _jc_soot_util_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_internal_JIdentityStmt$sub_refs	_jc_soot_jimple_internal_JIdentityStmt$sub_refs;
typedef struct _jc_soot_jimple_internal_JIdentityStmt$sub_nonrefs	_jc_soot_jimple_internal_JIdentityStmt$sub_nonrefs;
typedef struct _jc_soot_jimple_internal_JIdentityStmt$refs	_jc_soot_jimple_internal_JIdentityStmt$refs;
typedef struct _jc_soot_jimple_internal_JIdentityStmt$nonrefs	_jc_soot_jimple_internal_JIdentityStmt$nonrefs;
typedef struct _jc_soot_jimple_internal_JIdentityStmt$object	_jc_soot_jimple_internal_JIdentityStmt$object;

typedef const struct _jc_soot_jimple_internal_JIdentityStmt$vmethods	_jc_soot_jimple_internal_JIdentityStmt$vmethods;
typedef const struct _jc_soot_jimple_internal_JIdentityStmt$vtable	_jc_soot_jimple_internal_JIdentityStmt$vtable;
typedef const struct _jc_soot_jimple_internal_JIdentityStmt$vtype	_jc_soot_jimple_internal_JIdentityStmt$vtype;

// Constructors
extern void _jc_soot_jimple_internal_JIdentityStmt$method$_init$b3c9ec81c7d0a5b0(_jc_env *, struct _jc_soot_jimple_internal_JIdentityStmt$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_internal_JIdentityStmt$method$_init$76c8b23810ae9526(_jc_env *, struct _jc_soot_jimple_internal_JIdentityStmt$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_internal_JIdentityStmt$method$apply$cd67f53165014a6d(_jc_env *, struct _jc_soot_jimple_internal_JIdentityStmt$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_internal_JIdentityStmt$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_internal_JIdentityStmt$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_internal_JIdentityStmt$method$convertToBaf$0357e46cf55b475a(_jc_env *, struct _jc_soot_jimple_internal_JIdentityStmt$object *, struct _jc_soot_jimple_JimpleToBafContext$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_internal_JIdentityStmt$method$setLeftOp$8889dbc4befe13b8(_jc_env *, struct _jc_soot_jimple_internal_JIdentityStmt$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_internal_JIdentityStmt$method$setRightOp$43827eda9181e3de(_jc_env *, struct _jc_soot_jimple_internal_JIdentityStmt$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_internal_JIdentityStmt$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_internal_JIdentityStmt$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_internal_JIdentityStmt$method$toString$49ce0d4a4e59c2a6(_jc_env *, struct _jc_soot_jimple_internal_JIdentityStmt$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_internal_JIdentityStmt$method_info$apply$cd67f53165014a6d;
extern _jc_method _jc_soot_jimple_internal_JIdentityStmt$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_internal_JIdentityStmt$method_info$convertToBaf$0357e46cf55b475a;
extern _jc_method _jc_soot_jimple_internal_JIdentityStmt$method_info$setLeftOp$8889dbc4befe13b8;
extern _jc_method _jc_soot_jimple_internal_JIdentityStmt$method_info$setRightOp$43827eda9181e3de;
extern _jc_method _jc_soot_jimple_internal_JIdentityStmt$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_soot_jimple_internal_JIdentityStmt$method_info$toString$49ce0d4a4e59c2a6;

// Virtual methods structure
struct _jc_soot_jimple_internal_JIdentityStmt$vmethods {
	void	(*apply$cd67f53165014a6d)(_jc_env *, struct _jc_soot_jimple_internal_JIdentityStmt$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_internal_JIdentityStmt$object *) _JC_JCNI_ATTR;
	void	(*convertToBaf$0357e46cf55b475a)(_jc_env *, struct _jc_soot_jimple_internal_JIdentityStmt$object *, struct _jc_soot_jimple_JimpleToBafContext$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*setLeftOp$8889dbc4befe13b8)(_jc_env *, struct _jc_soot_jimple_internal_JIdentityStmt$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*setRightOp$43827eda9181e3de)(_jc_env *, struct _jc_soot_jimple_internal_JIdentityStmt$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_internal_JIdentityStmt$object *) _JC_JCNI_ATTR;
	void	(*toString$49ce0d4a4e59c2a6)(_jc_env *, struct _jc_soot_jimple_internal_JIdentityStmt$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_internal_JIdentityStmt$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractUnit$vmethods	soot_AbstractUnit;
	_jc_soot_jimple_internal_AbstractStmt$vmethods	soot_jimple_internal_AbstractStmt;
	_jc_soot_jimple_internal_AbstractDefinitionStmt$vmethods	soot_jimple_internal_AbstractDefinitionStmt;
	_jc_soot_jimple_internal_JIdentityStmt$vmethods	soot_jimple_internal_JIdentityStmt;
};

// Vtype
struct _jc_soot_jimple_internal_JIdentityStmt$vtype {
	_jc_type			type;
	_jc_soot_jimple_internal_JIdentityStmt$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_internal_JIdentityStmt$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_internal_JIdentityStmt$refs {
    _jc_soot_jimple_internal_JIdentityStmt$sub_refs	soot_jimple_internal_JIdentityStmt;
    _jc_soot_jimple_internal_AbstractDefinitionStmt$sub_refs	soot_jimple_internal_AbstractDefinitionStmt;
    _jc_soot_jimple_internal_AbstractStmt$sub_refs	soot_jimple_internal_AbstractStmt;
    _jc_soot_AbstractUnit$sub_refs	soot_AbstractUnit;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_internal_JIdentityStmt$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_internal_JIdentityStmt$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractUnit$sub_nonrefs	soot_AbstractUnit;
    _jc_soot_jimple_internal_AbstractStmt$sub_nonrefs	soot_jimple_internal_AbstractStmt;
    _jc_soot_jimple_internal_AbstractDefinitionStmt$sub_nonrefs	soot_jimple_internal_AbstractDefinitionStmt;
    _jc_soot_jimple_internal_JIdentityStmt$sub_nonrefs	soot_jimple_internal_JIdentityStmt;
};

// Object instance structure
struct _jc_soot_jimple_internal_JIdentityStmt$object {
	_jc_soot_jimple_internal_JIdentityStmt$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_internal_JIdentityStmt$vtype	*vtype;
	_jc_soot_jimple_internal_JIdentityStmt$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_internal_JIdentityStmt$vtype _jc_soot_jimple_internal_JIdentityStmt$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_internal_JIdentityStmt, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_internal_JIdentityStmt$class_object;

#endif	/* _JC_soot_jimple_internal_JIdentityStmt_H_ */
